// PhotonCollector.c
// PhotonCollector project
// Written by Dale Wheat - 31 July 2008

#include <avr/io.h>
#include <avr/sleep.h>
#include <avr/interrupt.h>

///////////////////////////////////////////////////////////////////////////////
// delay & timing functions
///////////////////////////////////////////////////////////////////////////////

void delay(unsigned int n) {

	while(n) {
		set_sleep_mode(SLEEP_MODE_IDLE);
		sleep_mode();
		n--;
	}
}

///////////////////////////////////////////////////////////////////////////////
// init_io() - initialize ATtiny13 input & output port
///////////////////////////////////////////////////////////////////////////////

void init_io(void) {

	// PORTB
	//			SOIC8
	//	name	DIP8	other functions
	//	----	----	----------------
	//	PB0		5		MOSI/AIN0/OC0A/PCINT0		red LED 1A
	//	PB1		6		MISO/AIN1/OC0B/INT0/PCINT1	red LED 1B
	//	PB2		7		SCK/ADC1/T0/PCINT2			red LED 2A
	//	PB3		2		PCINT3/CLKI/ADC3			red LED 2B
	//	PB4		3		PCINT4/ADC2
	//	PB5		1		PCINT5/-RESET/ADC0/dW

	PORTB = 0<<PORTB5 | 0<<PORTB4 | 0<<PORTB3 | 0<<PORTB2 | 1<<PORTB1 | 1<<PORTB0;
	DDRB = 0<<DDB5 | 0<<DDB4 | 1<<DDB3 | 1<<DDB2 | 1<<DDB1 | 1<<DDB0;
}

///////////////////////////////////////////////////////////////////////////////
// init_timer() - initialize ATtiny13 timer/counter
///////////////////////////////////////////////////////////////////////////////

void init_timer(void) {

	TCCR0A = 0<<COM0A1 | 0<<COM0A0 | 0<<COM0B1 | 0<<COM0B0 | 0<<WGM01 | 0<<WGM00;
	TCCR0B = 0<<FOC0A | 0<<FOC0B | 0<<WGM02 | 0<<CS02 | 1<<CS01 | 1<<CS00;

	TCNT0 = 0;
	OCR0A = 0;
	OCR0B = 0;

	TIMSK0 = 0<<OCIE0B | 0<<OCIE0A | 1<<TOIE0; // interrupts
}

///////////////////////////////////////////////////////////////////////////////
// init() - initialize everything
///////////////////////////////////////////////////////////////////////////////

void init(void) {

	init_io(); // initialize on-chip input & output port
	init_timer(); // initialize on-chip timer/counter

	sei(); // enable global interrupts
}

///////////////////////////////////////////////////////////////////////////////
// main() - main program function
///////////////////////////////////////////////////////////////////////////////

void main(void) {

	init(); // initialize everything

	while(1) {

		TCCR0B = 4; // slow
		delay(40);
		TCCR0B = 3; // fast
		delay(40);
	}
}

///////////////////////////////////////////////////////////////////////////////
// timer/counter0 overflow interrupt handler
///////////////////////////////////////////////////////////////////////////////

ISR(TIM0_OVF_vect) {

	PINB = 0x0F;
}

///////////////////////////////////////////////////////////////////////////////

// [end-of-file]
